#
# spec file for package python-spsdk
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without libalternatives
%{?sle15_python_module_pythons}
Name:           python-spsdk
Version:        2.1.1
Release:        3.1
Summary:        Unified, reliable and easy to use SW library working across NXP MCU portfolio
License:        BSD-3-Clause
URL:            https://github.com/nxp-mcuxpresso/spsdk
Source:         https://files.pythonhosted.org/packages/source/s/spsdk/spsdk-%{version}.tar.gz
# PATCH-FIX-OPENSUSE python-spsdk-remove_pypemicro.patch
Patch0:         python-spsdk-remove_pypemicro.patch
BuildRequires:  %{python_module flit}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  alts
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       alts
Requires:       python-asn1crypto
Requires:       python-astunparse
Requires:       python-bincopy
Requires:       python-bitstring
Requires:       python-click
Requires:       python-click-command-tree
Requires:       python-click-option-group
Requires:       python-colorama
Requires:       python-crcmod
Requires:       python-cryptography
Requires:       python-deepmerge
Requires:       python-fastjsonschema
Requires:       python-hexdump
Requires:       python-importlib_metadata
Requires:       python-libusbsio
Requires:       python-oscrypto
Requires:       python-platformdirs
Requires:       python-prettytable
Requires:       python-pylink-square
Requires:       python-pyocd
Requires:       python-pyserial
Requires:       python-requests
Requires:       python-ruamel.yaml
Requires:       python-sly
Requires:       python-typing-extensions
# Removed dependencies
# Requires:       python-pyocd-pemicro
# dependency no longer required due to Patch0
# Requires:       python-pypemicro
BuildArch:      noarch
%python_subpackages

%description
Secure Provisioning SDK (SPSDK) is unified, reliable and easy to use SW library working across NXP MCU portfolio providing strong foundation from quick customer prototyping up to production deployment.

%prep
%autosetup -p1 -n spsdk-%{version}

%build
%pyproject_wheel
find . -type f -name README.md -exec dos2unix {} +

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/blhost
%python_clone -a %{buildroot}%{_bindir}/ifr
%python_clone -a %{buildroot}%{_bindir}/nxpcrypto
%python_clone -a %{buildroot}%{_bindir}/nxpdebugmbox
%python_clone -a %{buildroot}%{_bindir}/nxpdevhsm
%python_clone -a %{buildroot}%{_bindir}/nxpdevscan
%python_clone -a %{buildroot}%{_bindir}/nxpele
%python_clone -a %{buildroot}%{_bindir}/nxpimage
%python_clone -a %{buildroot}%{_bindir}/pfr
%python_clone -a %{buildroot}%{_bindir}/sdphost
%python_clone -a %{buildroot}%{_bindir}/sdpshost
%python_clone -a %{buildroot}%{_bindir}/shadowregs
%python_clone -a %{buildroot}%{_bindir}/spsdk
%python_clone -a %{buildroot}%{_bindir}/tpconfig
%python_clone -a %{buildroot}%{_bindir}/tphost
%python_clone -a %{buildroot}%{_bindir}/dk6prog
%python_clone -a %{buildroot}%{_bindir}/nxpmemcfg
%python_clone -a %{buildroot}%{_bindir}/nxpwpc
# fix line endings
%python_expand find %{buildroot}%{$python_sitelib} -type f -exec dos2unix {} +
# remove shebangs
%python_expand find %{buildroot}%{$python_sitelib} -iname "*.py" -exec sed -i '1{/env python/d;}' {} +
# compile all here to avoid python-bytecode-inconsistent-mtime
%python_compileall
%python_expand %fdupes %{buildroot}%{$python_sitelib}
# remove unneccesary *.c and *.bin files
%python_expand rm -vf %{buildroot}%{$python_sitelib}/spsdk/data/cpu_data/*.c %{buildroot}%{$python_sitelib}/spsdk/data/cpu_data/*.bin

%pre
%python_libalternatives_reset_alternative blhost

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/spsdk/
%{python_sitelib}/spsdk-%{version}.dist-info/
%python_alternative %{_bindir}/blhost
%python_alternative %{_bindir}/ifr
%python_alternative %{_bindir}/nxpcrypto
%python_alternative %{_bindir}/nxpdebugmbox
%python_alternative %{_bindir}/nxpdevhsm
%python_alternative %{_bindir}/nxpdevscan
%python_alternative %{_bindir}/nxpele
%python_alternative %{_bindir}/nxpimage
%python_alternative %{_bindir}/pfr
%python_alternative %{_bindir}/sdphost
%python_alternative %{_bindir}/sdpshost
%python_alternative %{_bindir}/shadowregs
%python_alternative %{_bindir}/spsdk
%python_alternative %{_bindir}/tpconfig
%python_alternative %{_bindir}/tphost
%python_alternative %{_bindir}/dk6prog
%python_alternative %{_bindir}/nxpmemcfg
%python_alternative %{_bindir}/nxpwpc

%changelog
* Tue Jun 17 2025 Markéta Machová <mmachova@suse.com>
- Convert to libalternatives
* Wed Jul 17 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Require importlib_metadata
* Thu Mar 28 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 2.1.1:
  * New features
  - nxpcrypto:
  - add RSA-PSS support
  - nxpdevhsm:
  - support external devhsm provisioning
  * Bugfixes
  - dk6prog:
  - fix DK6 operations
  - nxpdevhsm:
  - fix buffer address MC56
  - nxpele:
  - fix write fuse
  - nxpimage:
  - add advanced params setting to configurations
    (padding, keys, timestamp, etc.)
  - fix manifest hash digest KW45/K32W1
* Tue Mar 26 2024 Daniel Garcia <daniel.garcia@suse.com>
- Add python-spsdk-remove_pypemicro.patch to remove dependency on
  python-pypemcro and pyocd-pemicro.
* Mon Mar 25 2024 Daniel Garcia <daniel.garcia@suse.com>
- Update to 2.1.0:
  * add signing commands (create, verify)
  * add subcommands for Fault Analysis Mode (export, parse, get-templates)
  * add printing the result of auth command
  * add dedicated plugin system
  * U-BOOT interface
  * add commit command
  * add commands related to release-container
  * enable IEE encryption for RT1180
  * add key exchange signed message
  * add signature provider for RT1xxx
  * support mcxn23x
  * deployment of new database
  * EL2GO mockup for S32K WPC
  * introduce memory configuration tool
  * fix get-trng state command
  * fix cmpa template
  * fix parsing ahab image for i.MX95
  * fix xmcd export command
  * fix certificate block as binary file
  * fix sb21 get-template command
  * fix export command
  * fix pfr generate command
  * fix default family parameter
* Sun Jan 14 2024 Dirk Müller <dmueller@suse.com>
- update to 2.0.1:
  * fix test memory AP address
  * Fix detection of input file for FCB in bootable image
  * fix IEE encryption for RT1180
  * fix signed MBI for Anguilla Nano
  * fix SB21 export with yaml config
  * fix behavior of the RKTH registers
  * fix invalid names of CRC field in database
  * fix setting a register value as raw value when loading from
    configuration
- update to 2.0.0:
  * dedicated plugin system
  * check of written data length in USB Interface
  * remove dependency on PyCryptodome
  * add rot command for calculating RoT hash
  * distinguish between fw version and image version
  * support YAML configuration for HAB
  * support build RT11xx image with ECC keys
  * support OSCCA
  * support AHAB NAND
  * implement HTTP Proxy Signature Provider
  * signature provider for OSCCA
  * add validation of signature in AHAB
  * support OTFAD for RT1010
  * export HAB from yaml config in bootable image
  * revision of offsets in AHAB container
  * command filter in SB 2.1 based on family
  * refactor memory types for mbi
  * add to AHAB key identifier for encrypted images
  * pfr/ifr:
  * remove devices subcommand
  * sdpshost:
  * connection support for iMX91 and iMX95
  * shadowregs:
  * unify endianness
  * tool for converting JSON configuration into YAML with
    comments
  * support mcxa1xx
  * unify naming: RKTH/RKHT
  * remove nxpkeygen and nxpcertgen apps, replaced by nxpcrypto
  * remove elftosb app, replaced by nxpcrypto
  * positional arguments replaced by options for all parameters
    with an exception to blhost, sdphost and dk6prog
  * remove backward compatibility with command get-cfg-template,
    replaced fully with get-template(s)
  * unify family name within all modules
  * remove lpc55xx from family names
  * fix error of SPI connection
  * add missing sdio in generate command
  * fix generate-keyblob IEE
  * fix issue with get-info command
  * fix certificate block in AHAB
  * fix signature in AHAB
  * fix some commands for SB21
  * fix non generated keys for AHAB parse
  * fix RAM images for LPC55Sxx
  * fix MBI signed for xip for MCXN9xx
  * fix sb21 export yaml errors
  * fix OTFAD with DUK
  * fix wrong core ID in parse for iMX93
  * fix binary certificate block for MBI
  * fix manifest for mcxn9xx
  * fix bootable image merge
  * fix in MBI configurations
  * fix missing parameters in MBI config in bootable-image parse
  * fix sb21 file generation without SBKEK
  * update list of supported MBI images for mcxn9xx
- drop python-spsdk-remove_pypemicro.patch (obsolete)
* Mon Oct 30 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 1.11.0:
  * New features
  - nxpimage:
  - enable signature providers for AHAB image and signed
    messages
  - add support for rt104x in bootable-image
  - tphost/tpconfig:
  - add possibility to check TP_RESPONSE only with NXP_PROD raw
    binary key
  - add support for mcxn9xx
  - add API for FuseLockedStatus
  - possibility to declare private keys with passphrase in
    signature provider config
  - add checking of written data length in usb interface
  - add support for dk6 tools
  * Bugfixes
  - nxpimage: fix offset on NAND memory in AHAB image
  - fix plugin error for signature Provider for sb21
* Mon Oct 30 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 1.10.1:
  * New features
  - nxpimage:
  - support encrypted image hab
  - support for RT11xx and RT10xx
  - improve OTFAD/IEE names generation
  - add API to retrieve info about fuses
  * Bugfixes
  - nxpimage:
  - fix XMCD load_from_config
  - fix IEE template
  - fix circular dependency in signature provider import
  - fix issue with loading keys as INT
  - not enable logging when spsdk is used as a library
* Wed May 31 2023 Johannes Kastl <kastl@b1-systems.de>
- do no longer package the *.c and *.bin files in
  spsdk/data/cpu_data/ (see
  https://github.com/nxp-mcuxpresso/spsdk/issues/60)
* Mon May 15 2023 Johannes Kastl <kastl@b1-systems.de>
- add patch python-spsdk-remove_pypemicro.patch to remove
  dependency on pypemicro, which contains a binary blob and cannot
  be distributed on OBS as is
  (see https://github.com/nxp-mcuxpresso/spsdk/issues/30)
- remove Requires for pyocd-pemicro
* Fri May 12 2023 Johannes Kastl <kastl@b1-systems.de>
- new package python-spsdk, required by pynitrokey
